@@ -1,7 +1,6 @@
-"""Library for managing Juju interfaces based on schemas.
-"""
-
-__version__ = "0.0.1"
+# Copyright 2022 Canonical Ltd.
+# See LICENSE file for licensing details.
+__version__ = "0.0.2"
 
 # flake8: noqa: F401,F402
 
